# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class SystemProtection_Static(type):
    def request_screen_unlock(cls) -> None: ...
    @_property
    def screen_locked(cls) -> bool: ...

@typing.final
class SystemProtection(winrt.system.Object, metaclass=SystemProtection_Static):
    pass




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_phone_system

__all__ = [
    "SystemProtection",
]

SystemProtection = _winrt_windows_phone_system.SystemProtection
